@@ -33,6 +33,7 @@
 #include <stddef.h>
 #include <stdarg.h>
 #include <stdlib.h>
+#include <string.h>
 
 
 CHEROKEE_BEGIN_DECLS
@@ -52,13 +53,11 @@ typedef struct {
 #define CHEROKEE_BUF_INIT  {NULL, 0, 0}
 
 #define cherokee_buffer_is_empty(b)        (BUF(b)->len == 0)
-#define cherokee_buffer_add_str(b,s)       cherokee_buffer_add (b, s, sizeof(s)-1)
+#define cherokee_buffer_add_str(b,s)       cherokee_buffer_add (b, s, CSZLEN(s))
 #define cherokee_buffer_cmp_str(b,s)       cherokee_buffer_cmp (b, s, sizeof(s))
 #define cherokee_buffer_case_cmp_str(b,s)  cherokee_buffer_case_cmp (b, s, sizeof(s))
 
 
-
-
 ret_t cherokee_buffer_new                (cherokee_buffer_t **buf);
 ret_t cherokee_buffer_free               (cherokee_buffer_t  *buf);
 ret_t cherokee_buffer_clean              (cherokee_buffer_t  *buf);
@@ -98,6 +97,8 @@ ret_t cherokee_buffer_ensure_size        (cherokee_buffer_t  *buf, size_t size);
 
 int   cherokee_buffer_is_endding         (cherokee_buffer_t  *buf, char c);
 char  cherokee_buffer_end_char           (cherokee_buffer_t  *buf);
+size_t cherokee_buffer_cnt_spn           (cherokee_buffer_t  *buf, int offset, char *str);
+size_t cherokee_buffer_cnt_cspn          (cherokee_buffer_t  *buf, int offset, char *str);
 
 crc_t cherokee_buffer_crc32              (cherokee_buffer_t  *buf);
 ret_t cherokee_buffer_decode             (cherokee_buffer_t  *buf);
