@@ -31,6 +31,10 @@
 # include <sys/select.h>
 #endif
 
+#ifdef HAVE_SYS_TIME_H
+# include <sys/time.h>
+#endif
+
 #ifndef INFTIM
 # define INFTIM -1
 #endif
