@@ -27,14 +27,15 @@
 
 #include "common-internal.h"
 #include "handler.h"
+#include "module_loader.h"
 
 
 /* Library init function
  */
-void nn_init ();
+void MODULE_INIT(nn) (cherokee_module_loader_t *loader);
+
 
 ret_t cherokee_handler_nn_new  (cherokee_handler_t **hdl, void *cnt, cherokee_table_t *properties);
 ret_t cherokee_handler_nn_init (cherokee_handler_t  *hdl);
 
-
 #endif /* CHEROKEE_CONNECTION_HANDLER_NN_H */
