@@ -31,24 +31,22 @@
 #include "list.h"
 
 typedef struct {
-	cherokee_handler_t          handler;
+	cherokee_handler_t    handler;
 
-	char                       *target_url;
-	int                         target_url_len;
+	char                 *target_url;
+	int                   target_url_len;
 
-	list_t                     *regex_list_ref;
-	void                       *regex_list_cre;
+	list_t               *regex_list_ref;
+	void                 *regex_list_cre;
 
-	cherokee_boolean_t          is_hidden;	
-	cherokee_boolean_t          use_previous_match;
+	cherokee_boolean_t    use_previous_match;
 
 } cherokee_handler_redir_t;
 
 #define REHANDLER(x)  ((cherokee_handler_redir_t *)(x))
 
 
-void init_redir (cherokee_module_loader_t *loader);
-
+void MODULE_INIT(redir) (cherokee_module_loader_t *loader);
 ret_t cherokee_handler_redir_new (cherokee_handler_t **hdl, void *cnt, cherokee_table_t *properties);
 
 /* virtual methods implementation
