@@ -82,27 +82,28 @@ typedef enum {
 } cherokee_http_upgrade_t;
 
 typedef enum {
-	http_unset                 = 0,
-	http_continue              = 100,
-	http_switching_protocols   = 101,
-	http_ok                    = 200,
-	http_accepted              = 202,
-	http_partial_content       = 206,
-	http_moved_permanently     = 301,
-	http_moved_temporarily     = 302,
-	http_see_other             = 303,
-	http_not_modified          = 304,
-	http_bad_request           = 400,
-	http_unauthorized          = 401,
-	http_access_denied         = 403,
-	http_not_found             = 404,
-	http_method_not_allowed    = 405,
-	http_length_required       = 411,
-	http_request_uri_too_long  = 414,
-	http_range_not_satisfiable = 416,
-	http_upgrade_required      = 426,
-	http_internal_error        = 500,
-	http_service_unavailable   = 503
+	http_unset                    = 0,
+	http_continue                 = 100,
+	http_switching_protocols      = 101,
+	http_ok                       = 200,
+	http_accepted                 = 202,
+	http_partial_content          = 206,
+	http_moved_permanently        = 301,
+	http_moved_temporarily        = 302,
+	http_see_other                = 303,
+	http_not_modified             = 304,
+	http_bad_request              = 400,
+	http_unauthorized             = 401,
+	http_access_denied            = 403,
+	http_not_found                = 404,
+	http_method_not_allowed       = 405,
+	http_length_required          = 411,
+	http_request_entity_too_large = 413,
+	http_request_uri_too_long     = 414,
+	http_range_not_satisfiable    = 416,
+	http_upgrade_required         = 426,
+	http_internal_error           = 500,
+	http_service_unavailable      = 503
 } cherokee_http_t;
 
 /*                                        0         1         2         3         4         5         6         7
@@ -122,6 +123,7 @@ typedef enum {
 #define http_not_found_string             "404 Not Found"
 #define http_method_not_allowed_string    "405 Method Not Allowed"
 #define http_length_required_string       "411 Length Required"
+#define http_request_entity_too_large_string "413 Request Entity too large"
 #define http_request_uri_too_long_string  "414 Request-URI too long"
 #define http_range_not_satisfiable_string "416 Requested range not satisfiable"
 #define http_upgrade_required_string      "426 Upgrade Required"
@@ -145,6 +147,10 @@ typedef enum {
 				   (m == http_propfind) || \
 				   (m == http_proppatch))
 
+#define http_code_with_body(e)   ((e != http_continue)            && \
+				  (e != http_not_modified)        && \
+				  (e != http_switching_protocols))
+
 ret_t cherokee_http_method_to_string  (cherokee_http_method_t  method,  const char **str, cuint_t *str_len);
 ret_t cherokee_http_version_to_string (cherokee_http_version_t version, const char **str, cuint_t *str_len);
 ret_t cherokee_http_code_to_string    (cherokee_http_t code, const char **str);
