@@ -66,7 +66,7 @@ typedef struct {
 	cherokee_iocache_entry_t base;
 	time_t                   stat_update;
 	time_t                   mmap_update;
-	cint_t                   mmap_usage;
+	cint_t                   ref_counter;
 	cint_t                   usages;
 
 #ifdef HAVE_PTHREAD
@@ -168,7 +168,7 @@ iocache_clean_up_each (const char *key, void *value, void *param)
 
 	/* Is it in use?
 	 */
-	if (PRIV(file)->mmap_usage > 0) {
+	if (PRIV(file)->ref_counter > 0) {
 		return true;
 	}
 
@@ -197,8 +197,8 @@ iocache_entry_new (cherokee_iocache_entry_t **entry)
 
 	PRIV(n)->stat_update = 0;
 	PRIV(n)->mmap_update = 0;
-	PRIV(n)->mmap_usage  = 0;
 	PRIV(n)->usages      = 0;
+	PRIV(n)->ref_counter = 1;
 	
 	CHEROKEE_MUTEX_INIT (&PRIV(n)->lock, NULL);
 
@@ -381,6 +381,13 @@ cherokee_iocache_free_default (cherokee_iocache_t *iocache)
 	return cherokee_iocache_free (iocache);	
 }
 
+static void
+hit (cherokee_iocache_t *iocache, cherokee_iocache_entry_t *file)
+{
+	PRIV(file)->usages++;
+	iocache->files_usages++;
+}
+
 
 ret_t 
 cherokee_iocache_stat_get (cherokee_iocache_t *iocache, char *filename, cherokee_iocache_entry_t **file)
@@ -404,8 +411,8 @@ cherokee_iocache_stat_get (cherokee_iocache_t *iocache, char *filename, cherokee
 			}
 		}
 
-		PRIV(new)->usages++;
-		iocache->files_usages++;
+		hit (iocache, *file);
+		PRIV(*file)->ref_counter++;
 
 		CHEROKEE_MUTEX_UNLOCK (&iocache->files_lock);
 		return ret_ok;
@@ -424,11 +431,10 @@ cherokee_iocache_stat_get (cherokee_iocache_t *iocache, char *filename, cherokee
 	/* Add to the table
 	 */
 	cherokee_table_add (&iocache->files, filename, (void *)new);
+	iocache->files_num++;
 
 	*file = new;
-	PRIV(new)->usages++;
-	iocache->files_num++;
-	iocache->files_usages++;
+	hit (iocache, new);
 
 	CHEROKEE_MUTEX_UNLOCK (&iocache->files_lock);
 	return ret_ok;
@@ -465,8 +471,8 @@ cherokee_iocache_mmap_get_w_fd (cherokee_iocache_t *iocache, char *filename, int
 			}
 		}
 
-		PRIV(new)->usages++;
-		iocache->files_usages++;
+		hit (iocache, new);
+		PRIV(new)->ref_counter++;
 
 		CHEROKEE_MUTEX_UNLOCK (&iocache->files_lock);
 		return ret_ok;
@@ -475,18 +481,15 @@ cherokee_iocache_mmap_get_w_fd (cherokee_iocache_t *iocache, char *filename, int
 	/* Create a new entry
 	 */
 	iocache_entry_new (&new);
-
-	PRIV(new)->mmap_usage++;
 	iocache_entry_update_mmap (new, filename, fd, iocache);
 
 	/* Add to the table
 	 */
 	cherokee_table_add (&iocache->files, filename, new);
+	iocache->files_num++;
 
 	*file = new;
-	PRIV(new)->usages++;
-	iocache->files_num++;
-	iocache->files_usages++;
+	hit (iocache, new);
 
 	CHEROKEE_MUTEX_UNLOCK (&iocache->files_lock);
 	return ret_ok;
@@ -520,8 +523,8 @@ cherokee_iocache_mmap_lookup (cherokee_iocache_t *iocache, char *filename, chero
 
 	/* Return it
 	 */
-	PRIV(new)->usages++;
-	iocache->files_usages++;
+	hit (iocache, new);
+	PRIV(new)->ref_counter++;
 
 	CHEROKEE_MUTEX_UNLOCK (&iocache->files_lock);
 	return ret_ok;
@@ -538,8 +541,11 @@ cherokee_iocache_mmap_get (cherokee_iocache_t *iocache, char *filename, cherokee
 ret_t 
 cherokee_iocache_mmap_release (cherokee_iocache_t *iocache, cherokee_iocache_entry_t *file)
 {
+	if (file == NULL)
+		return ret_not_found;
+
 	CHEROKEE_MUTEX_LOCK (&iocache->files_lock);
-	PRIV(file)->mmap_usage--;
+	PRIV(file)->ref_counter--;
 	CHEROKEE_MUTEX_UNLOCK (&iocache->files_lock);
 
 	return ret_ok;
