@@ -93,17 +93,16 @@ common_server_initialization (cherokee_server_t *srv)
 		PRINT_MSG_S ("Couldn't read the config file\n");
 		return ret_error;
 	}
-		
+
+	if (daemon_mode)
+		cherokee_server_daemonize (srv);
+
+	cherokee_server_write_pidfile (srv);
+
 	ret = cherokee_server_init (srv);
 	if (ret != ret_ok) return ret_error;
 
-	if (daemon_mode) {
-		cherokee_server_daemonize (srv);
-	}
-
-	cherokee_server_write_pidfile (srv);
 	cherokee_server_unlock_threads (srv);
-
 	return ret_ok;
 }
 
