@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001, 2002, 2003, 2004, 2005 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2006 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -79,7 +79,8 @@ _add (cherokee_regex_table_t *table, char *pattern, void **regex)
 
 	tmp = (pcre*)cherokee_table_get_val (table->cache, pattern);
 	if (tmp != NULL) {
-		*regex = tmp;
+		if (regex != NULL)
+			*regex = tmp;
 
 		CHEROKEE_RWLOCK_UNLOCK (&table->rwlock);
 		return ret_ok;
