@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001, 2002, 2003, 2004, 2005 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2006 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -34,6 +34,9 @@ cherokee_reqs_list_entry_new  (cherokee_reqs_list_entry_t **entry)
 	 */
 	cherokee_config_entry_init (&n->base_entry);
 
+	memset (n->ovector, 0, sizeof(int)*OVECTOR_LEN);
+	n->ovecsize = 0;
+
 	/* Init properties
 	 */
 	cherokee_buffer_init (&n->request);
