@@ -477,7 +477,7 @@ cherokee_socket_shutdown (cherokee_socket_t *socket, int how)
 
 	re = shutdown (socket->socket, how);	
 
-	return (re == 0)? ret_ok : ret_error;
+	return (re == 0) ? ret_ok : ret_error;
 }
 
 
@@ -794,8 +794,8 @@ cherokee_read (cherokee_socket_t *socket, char *buf, int buf_size, size_t *done)
 	/* Plain read
 	 */
 	if (unlikely (buf == NULL)) {
-		static char trash[256];
-		len = recv (SOCKET_FD(socket), trash, 256, 0);
+		static char trash[4096];
+		len = recv (SOCKET_FD(socket), trash, sizeof(trash), 0);
 	} else {
 		len = recv (SOCKET_FD(socket), buf, buf_size, 0);
 	}
@@ -1124,13 +1124,12 @@ cherokee_socket_init_client_tls (cherokee_socket_t *socket)
 #ifdef HAVE_TLS
 	int re;
 
-	socket->is_tls = TLS;
-
 # ifdef HAVE_GNUTLS
-	const int kx_priority[] = {GNUTLS_KX_ANON_DH, 0};
-
+	const int                        kx_priority[] = {GNUTLS_KX_ANON_DH, 0};
 	gnutls_anon_client_credentials   anoncred;
 	
+	socket->is_tls = TLS;
+
 	/* Acredentials
 	 */
 	gnutls_anon_allocate_client_credentials(&anoncred);
@@ -1164,6 +1163,7 @@ cherokee_socket_init_client_tls (cherokee_socket_t *socket)
 		 (re == GNUTLS_E_INTERRUPTED));
 
 # elif defined(HAVE_OPENSSL)
+	socket->is_tls = TLS;
 
 	/* New context
 	 */
