@@ -164,7 +164,10 @@ typedef struct {
 
 ret_t cherokee_socket_new           (cherokee_socket_t **socket);
 ret_t cherokee_socket_free          (cherokee_socket_t  *socket);
-ret_t cherokee_socket_clean         (cherokee_socket_t  *socket);
+
+ret_t cherokee_socket_init          (cherokee_socket_t *socket);
+ret_t cherokee_socket_mrproper      (cherokee_socket_t *socket);
+ret_t cherokee_socket_clean         (cherokee_socket_t *socket);
 
 ret_t cherokee_socket_init_tls        (cherokee_socket_t *socket, cherokee_virtual_server_t *vserver);
 ret_t cherokee_socket_init_client_tls (cherokee_socket_t *socket);
@@ -182,8 +185,8 @@ ret_t cherokee_socket_set_timeout   (cherokee_socket_t *socket, cuint_t timeout)
 
 ret_t cherokee_socket_ntop          (cherokee_socket_t *socket, char *buf, size_t buf_size);
 ret_t cherokee_socket_pton          (cherokee_socket_t *socket, cherokee_buffer_t *buf);
-ret_t cherokee_socket_set_status    (cherokee_socket_t *socket, cherokee_socket_status_t);
 ret_t cherokee_socket_gethostbyname (cherokee_socket_t *socket, cherokee_buffer_t *hostname);
+ret_t cherokee_socket_set_status    (cherokee_socket_t *socket, cherokee_socket_status_t status);
 
 
 /* Low level functions
