@@ -38,11 +38,7 @@
 #define CRYPT_SALT_LENGTH 2
 
 
-cherokee_module_info_validator_t MODULE_INFO(htpasswd) = {
-	.module.type     = cherokee_validator,                 /* type     */
-	.module.new_func = cherokee_validator_htpasswd_new,    /* new func */
-	.valid_methods   = http_auth_basic                     /* methods  */
-};
+VALIDATOR_MODULE_INFO_INIT_EASY (htpasswd, http_auth_basic);
 
 
 ret_t 
