@@ -30,11 +30,8 @@
 #include "module_loader.h"
 
 
-cherokee_module_info_validator_t MODULE_INFO(plain) = {
-	.module.type     = cherokee_validator,                 /* type     */
-	.module.new_func = cherokee_validator_plain_new,       /* new func */
-	.valid_methods   = http_auth_basic | http_auth_digest  /* methods  */
-};
+VALIDATOR_MODULE_INFO_INIT_EASY (plain, http_auth_basic | http_auth_digest);
+
 
 ret_t 
 cherokee_validator_plain_new (cherokee_validator_plain_t **plain, cherokee_table_t *properties)
