@@ -28,12 +28,8 @@ class Test (TestBase):
                                        }
                                     }
                                     
-                                    Extension php {
-                                      Handler phpcgi {
-                                         Interpreter %s
-                                      }
-                                    }
-                                 }""" % (HOST, host_dir, PHPCGI_PATH)
+                                    %s
+                                 }""" % (HOST, host_dir, self.php_conf)
 
         self.WriteFile (host_dir, "index.php", 0444, '<?php echo "%s" ?>' %(MAGIC))
         
